==> bluedevil-5.1.95.tar.xz: bluedevil-5.1.95/src/sendfile/pages/selectdeviceandfilespage.h <==
/*****************************************************************************
 * This file is part of the KDE project                                      *
 *                                                                           *
 * Copyright (C) 2010-2011 Alejandro Fiestas Olivares <afiestas@kde.org>     *
 * Copyright (C) 2010-2011 UFO Coders <info@ufocoders.com>                   *
 *                                                                           *
 * This library is free software; you can redistribute it and/or             *
 * modify it under the terms of the GNU Library General Public               *
 * License as published by the Free Software Foundation; either              *
 * version 2 of the License, or (at your option) any later version.          *
 *                                                                           *
 * This library is distributed in the hope that it will be useful,           *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
 * Library General Public License for more details.                          *
 *                                                                           *
 * You should have received a copy of the GNU Library General Public License *
 * along with this library; see the file COPYING.LIB.  If not, write to      *
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
 * Boston, MA 02110-1301, USA.                                               *
 *****************************************************************************/

#ifndef SELECTDEVICEANDFILESPAGE_H
#define SELECTDEVICEANDFILESPAGE_H

#include "ui_selectfilediscover.h"

#include <QWizardPage>

class KUrl;
class QWizard;
class QFileDialog;

namespace BlueDevil {
    class Device;
}
using namespace BlueDevil;

class SelectDeviceAndFilesPage : public QWizardPage ,
        public Ui::SelectFileDiscover
{
Q_OBJECT
public:
    SelectDeviceAndFilesPage(QWidget* parent = 0);

    virtual bool isComplete() const;

private Q_SLOTS:
    void deviceSelected(Device*);
    void openFileDialog();
    void selectionChanged();

private:
    QFileDialog *m_dialog;
};

#endif // SELECTDEVICEANDFILESPAGE_H

==> bluedevil-5.3.2.tar.xz: bluedevil-5.3.2/src/sendfile/pages/selectdeviceandfilespage.h <==
/*****************************************************************************
 * This file is part of the KDE project                                      *
 *                                                                           *
 * Copyright (C) 2010-2011 Alejandro Fiestas Olivares <afiestas@kde.org>     *
 * Copyright (C) 2010-2011 UFO Coders <info@ufocoders.com>                   *
 *                                                                           *
 * This library is free software; you can redistribute it and/or             *
 * modify it under the terms of the GNU Library General Public               *
 * License as published by the Free Software Foundation; either              *
 * version 2 of the License, or (at your option) any later version.          *
 *                                                                           *
 * This library is distributed in the hope that it will be useful,           *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
 * Library General Public License for more details.                          *
 *                                                                           *
 * You should have received a copy of the GNU Library General Public License *
 * along with this library; see the file COPYING.LIB.  If not, write to      *
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
 * Boston, MA 02110-1301, USA.                                               *
 *****************************************************************************/

#ifndef SELECTDEVICEANDFILESPAGE_H
#define SELECTDEVICEANDFILESPAGE_H

#include "ui_selectfilediscover.h"

#include <QWizardPage>

#include <BluezQt/Types>

class QFileDialog;
class SendFileWizard;

class SelectDeviceAndFilesPage : public QWizardPage, public Ui::SelectFileDiscover
{
    Q_OBJECT

public:
    explicit SelectDeviceAndFilesPage(SendFileWizard *wizard);

    bool isComplete() const Q_DECL_OVERRIDE;

private Q_SLOTS:
    void deviceSelected(BluezQt::DevicePtr device);
    void openFileDialog();

private:
    QFileDialog *m_dialog;
    SendFileWizard *m_wizard;
};

#endif // SELECTDEVICEANDFILESPAGE_H
